#!/bin/bash
#==============================================================================
# Copyright and license info is available in the LICENSE file included with
# the Server Deployment Package (SDP), and also available online:
# https://swarm.workshop.perforce.com/projects/perforce-software-sdp/view/main/LICENSE
#------------------------------------------------------------------------------

# This script is used to change the role of a rhw old master server to the standby.
# You need to supply the instance number and the standby ID as a parameter to the script.
#
#
export SDP_INSTANCE=${SDP_INSTANCE:-Undefined} 
export SDP_INSTANCE=${1:-$SDP_INSTANCE} 
if [[ $SDP_INSTANCE == Undefined ]]; then 
   echo "Instance parameter not supplied." 
   echo "You must supply the Perforce instance as a parameter to this script." 
   exit 1 
fi 

export STANDBY_ID=${STANDBY_ID:-Undefined} 
export STANDBY_ID=${2:-$STANDBY_ID} 
if [[ $STANDBY_ID == Undefined ]]; then 
   echo "Standby ID parameter not supplied." 
   echo "You must supply the standby server ID as parameter 2 to this script." 
   exit 1 
fi 

. /p4/common/bin/p4_vars $SDP_INSTANCE
. /p4/common/bin/backup_functions.sh
LOGFILE=$LOGS/convert_standby_to_master.log

######### Start of Script ##########
check_vars
set_vars
check_uid
check_dirs
log "Start failover"
stop_p4d
echo $STANDBY_ID > $P4ROOT/server.id
echo p4d_standby > $P4ROOT/sdp_server_type.txt
rm -f $P4JOURNAL
rm -f ${P4ROOT}/state*
rm -f ${P4ROOT}/rdb.lbr
start_p4d
log "End failover"
